==> kubernetes-model-kustomize-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/PatchFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PatchFluentImpl<A extends PatchFluent<A>> extends BaseFluent<A> implements PatchFluent<A>{
  public PatchFluentImpl() {
  }
  public PatchFluentImpl(Patch instance) {
    this.withOptions(instance.getOptions()); 
    this.withPatch(instance.getPatch()); 
    this.withPath(instance.getPath()); 
    this.withTarget(instance.getTarget()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Map<String,Boolean> options;
  private String patch;
  private String path;
  private SelectorBuilder target;
  private Map<String,Object> additionalProperties;
  public A addToOptions(String key,Boolean value) {
    if(this.options == null && key != null && value != null) { this.options = new LinkedHashMap(); }
    if(key != null && value != null) {this.options.put(key, value);} return (A)this;
  }
  public A addToOptions(Map<String,Boolean> map) {
    if(this.options == null && map != null) { this.options = new LinkedHashMap(); }
    if(map != null) { this.options.putAll(map);} return (A)this;
  }
  public A removeFromOptions(String key) {
    if(this.options == null) { return (A) this; }
    if(key != null && this.options != null) {this.options.remove(key);} return (A)this;
  }
  public A removeFromOptions(Map<String,Boolean> map) {
    if(this.options == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.options != null){this.options.remove(key);}}} return (A)this;
  }
  public Map<String,Boolean> getOptions() {
    return this.options;
  }
  public <K,V>A withOptions(Map<String,Boolean> options) {
    if (options == null) { this.options =  null;} else {this.options = new LinkedHashMap(options);} return (A) this;
  }
  public Boolean hasOptions() {
    return this.options != null;
  }
  public String getPatch() {
    return this.patch;
  }
  public A withPatch(String patch) {
    this.patch=patch; return (A) this;
  }
  public Boolean hasPatch() {
    return this.patch != null;
  }
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public Selector getTarget() {
    return this.target!=null ?this.target.build():null;
  }
  public Selector buildTarget() {
    return this.target!=null ?this.target.build():null;
  }
  public A withTarget(Selector target) {
    _visitables.get("target").remove(this.target);
    if (target!=null){ this.target= new SelectorBuilder(target); _visitables.get("target").add(this.target);} else { this.target = null; _visitables.get("target").remove(this.target); } return (A) this;
  }
  public Boolean hasTarget() {
    return this.target != null;
  }
  public PatchFluent.TargetNested<A> withNewTarget() {
    return new PatchFluentImpl.TargetNestedImpl();
  }
  public PatchFluent.TargetNested<A> withNewTargetLike(Selector item) {
    return new PatchFluentImpl.TargetNestedImpl(item);
  }
  public PatchFluent.TargetNested<A> editTarget() {
    return withNewTargetLike(getTarget());
  }
  public PatchFluent.TargetNested<A> editOrNewTarget() {
    return withNewTargetLike(getTarget() != null ? getTarget(): new SelectorBuilder().build());
  }
  public PatchFluent.TargetNested<A> editOrNewTargetLike(Selector item) {
    return withNewTargetLike(getTarget() != null ? getTarget(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PatchFluentImpl that = (PatchFluentImpl) o;
    if (options != null ? !options.equals(that.options) :that.options != null) return false;
    if (patch != null ? !patch.equals(that.patch) :that.patch != null) return false;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (target != null ? !target.equals(that.target) :that.target != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(options,  patch,  path,  target,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (options != null && !options.isEmpty()) { sb.append("options:"); sb.append(options + ","); }
    if (patch != null) { sb.append("patch:"); sb.append(patch + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (target != null) { sb.append("target:"); sb.append(target + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class TargetNestedImpl<N> extends SelectorFluentImpl<PatchFluent.TargetNested<N>> implements PatchFluent.TargetNested<N>,Nested<N>{
    TargetNestedImpl(Selector item) {
      this.builder = new SelectorBuilder(this, item);
    }
    TargetNestedImpl() {
      this.builder = new SelectorBuilder(this);
    }
    SelectorBuilder builder;
    public N and() {
      return (N) PatchFluentImpl.this.withTarget(builder.build());
    }
    public N endTarget() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-kustomize-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/PatchFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PatchFluentImpl<A extends PatchFluent<A>> extends BaseFluent<A> implements PatchFluent<A>{
  public PatchFluentImpl() {
  }
  public PatchFluentImpl(Patch instance) {
    if (instance != null) {
      this.withOptions(instance.getOptions());
      this.withPatch(instance.getPatch());
      this.withPath(instance.getPath());
      this.withTarget(instance.getTarget());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Map<String,Boolean> options;
  private String patch;
  private String path;
  private SelectorBuilder target;
  private Map<String,Object> additionalProperties;
  public A addToOptions(String key,Boolean value) {
    if(this.options == null && key != null && value != null) { this.options = new LinkedHashMap(); }
    if(key != null && value != null) {this.options.put(key, value);} return (A)this;
  }
  public A addToOptions(Map<String,Boolean> map) {
    if(this.options == null && map != null) { this.options = new LinkedHashMap(); }
    if(map != null) { this.options.putAll(map);} return (A)this;
  }
  public A removeFromOptions(String key) {
    if(this.options == null) { return (A) this; }
    if(key != null && this.options != null) {this.options.remove(key);} return (A)this;
  }
  public A removeFromOptions(Map<String,Boolean> map) {
    if(this.options == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.options != null){this.options.remove(key);}}} return (A)this;
  }
  public Map<String,Boolean> getOptions() {
    return this.options;
  }
  public <K,V>A withOptions(Map<String,Boolean> options) {
    if (options == null) { this.options =  null;} else {this.options = new LinkedHashMap(options);} return (A) this;
  }
  public Boolean hasOptions() {
    return this.options != null;
  }
  public String getPatch() {
    return this.patch;
  }
  public A withPatch(String patch) {
    this.patch=patch; return (A) this;
  }
  public Boolean hasPatch() {
    return this.patch != null;
  }
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public Selector getTarget() {
    return this.target!=null ?this.target.build():null;
  }
  public Selector buildTarget() {
    return this.target!=null ?this.target.build():null;
  }
  public A withTarget(Selector target) {
    _visitables.get("target").remove(this.target);
    if (target!=null){ this.target= new SelectorBuilder(target); _visitables.get("target").add(this.target);} else { this.target = null; _visitables.get("target").remove(this.target); } return (A) this;
  }
  public Boolean hasTarget() {
    return this.target != null;
  }
  public PatchFluentImpl.TargetNested<A> withNewTarget() {
    return new PatchFluentImpl.TargetNestedImpl();
  }
  public PatchFluentImpl.TargetNested<A> withNewTargetLike(Selector item) {
    return new PatchFluentImpl.TargetNestedImpl(item);
  }
  public PatchFluentImpl.TargetNested<A> editTarget() {
    return withNewTargetLike(getTarget());
  }
  public PatchFluentImpl.TargetNested<A> editOrNewTarget() {
    return withNewTargetLike(getTarget() != null ? getTarget(): new SelectorBuilder().build());
  }
  public PatchFluentImpl.TargetNested<A> editOrNewTargetLike(Selector item) {
    return withNewTargetLike(getTarget() != null ? getTarget(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PatchFluentImpl that = (PatchFluentImpl) o;
    if (!java.util.Objects.equals(options, that.options)) return false;

    if (!java.util.Objects.equals(patch, that.patch)) return false;

    if (!java.util.Objects.equals(path, that.path)) return false;

    if (!java.util.Objects.equals(target, that.target)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(options,  patch,  path,  target,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (options != null && !options.isEmpty()) { sb.append("options:"); sb.append(options + ","); }
    if (patch != null) { sb.append("patch:"); sb.append(patch + ","); }
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (target != null) { sb.append("target:"); sb.append(target + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class TargetNestedImpl<N> extends SelectorFluentImpl<PatchFluentImpl.TargetNested<N>> implements PatchFluentImpl.TargetNested<N>,Nested<N>{
    TargetNestedImpl(Selector item) {
      this.builder = new SelectorBuilder(this, item);
    }
    TargetNestedImpl() {
      this.builder = new SelectorBuilder(this);
    }
    SelectorBuilder builder;
    public N and() {
      return (N) PatchFluentImpl.this.withTarget(builder.build());
    }
    public N endTarget() {
      return and();
    }
    
  }
  
}
